@@ -81,7 +81,7 @@ void MainMenu::initSuperMenu(QMenu* superMenu) const
     superMenu->addAction(m_actions[QSL("File/OpenFile")]);
     if (mApp->sessionManager()) {
         superMenu->addSeparator();
-        QMenu* sessionsSubmenu = new QMenu(tr("Sessions"));
+        auto* sessionsSubmenu = new QMenu(tr("Sessions"));
         connect(sessionsSubmenu, SIGNAL(aboutToShow()), mApp->sessionManager(), SLOT(aboutToShowSessionsMenu()));
         superMenu->addMenu(sessionsSubmenu);
         superMenu->addAction(m_actions[QSL("File/SessionManager")]);
@@ -119,7 +119,7 @@ QAction* MainMenu::action(const QString &name) const
 
 void MainMenu::showAboutDialog()
 {
-    AboutDialog* dialog = new AboutDialog(m_window);
+    auto* dialog = new AboutDialog(m_window);
     dialog->open();
 }
 
@@ -295,7 +295,7 @@ void MainMenu::webSearch()
 void MainMenu::showSiteInfo()
 {
     if (m_window && SiteInfo::canShowSiteInfo(m_window->weView()->url())) {
-        SiteInfo* info = new SiteInfo(m_window->weView());
+        auto* info = new SiteInfo(m_window->weView());
         info->show();
     }
 }
@@ -309,7 +309,7 @@ void MainMenu::showDownloadManager()
 
 void MainMenu::showCookieManager()
 {
-    CookieManager* m = new CookieManager(m_window);
+    auto* m = new CookieManager(m_window);
     m->show();
     m->raise();
 }
@@ -321,7 +321,7 @@ void MainMenu::toggleWebInspector()
 
 void MainMenu::showClearRecentHistoryDialog()
 {
-    ClearPrivateData* dialog = new ClearPrivateData(m_window);
+    auto* dialog = new ClearPrivateData(m_window);
     dialog->open();
 }
 
@@ -418,7 +418,7 @@ void MainMenu::aboutToShowSuperMenu()
 
 void MainMenu::aboutToShowToolbarsMenu()
 {
-    QMenu* menu = qobject_cast<QMenu*>(sender());
+    auto* menu = qobject_cast<QMenu*>(sender());
     Q_ASSERT(menu);
 
     if (m_window) {
@@ -429,7 +429,7 @@ void MainMenu::aboutToShowToolbarsMenu()
 
 void MainMenu::aboutToShowSidebarsMenu()
 {
-    QMenu* menu = qobject_cast<QMenu*>(sender());
+    auto* menu = qobject_cast<QMenu*>(sender());
     Q_ASSERT(menu);
 
     if (m_window) {
@@ -439,7 +439,7 @@ void MainMenu::aboutToShowSidebarsMenu()
 
 void MainMenu::aboutToShowEncodingMenu()
 {
-    QMenu* menu = qobject_cast<QMenu*>(sender());
+    auto* menu = qobject_cast<QMenu*>(sender());
     Q_ASSERT(menu);
 
     if (m_window) {
@@ -464,26 +464,26 @@ void MainMenu::init()
     m_actions[QSL(name)] = action
 
     // Standard actions - needed on Mac to be placed correctly in "application" menu
-    QAction* action = new QAction(QIcon::fromTheme(QSL("help-about")), tr("&About Falkon"), this);
+    auto* action = new QAction(QIcon::fromTheme(QSL("help-about")), tr("&About Falkon"), this);
     action->setMenuRole(QAction::AboutRole);
-    connect(action, SIGNAL(triggered()), this, SLOT(showAboutDialog()));
+    connect(action, &QAction::triggered, this, &MainMenu::showAboutDialog);
     m_actions[QSL("Standard/About")] = action;
 
     action = new QAction(IconProvider::settingsIcon(), tr("Pr&eferences"), this);
     action->setMenuRole(QAction::PreferencesRole);
     action->setShortcut(QKeySequence(QKeySequence::Preferences));
-    connect(action, SIGNAL(triggered()), this, SLOT(showPreferences()));
+    connect(action, &QAction::triggered, this, &MainMenu::showPreferences);
     m_actions[QSL("Standard/Preferences")] = action;
 
     action = new QAction(QIcon::fromTheme(QSL("application-exit")), tr("Quit"), this);
     action->setMenuRole(QAction::QuitRole);
     // shortcut set from browserwindow
-    connect(action, SIGNAL(triggered()), this, SLOT(quitApplication()));
+    connect(action, &QAction::triggered, this, &MainMenu::quitApplication);
     m_actions[QSL("Standard/Quit")] = action;
 
     // File menu
     m_menuFile = new QMenu(tr("&File"));
-    connect(m_menuFile, SIGNAL(aboutToShow()), this, SLOT(aboutToShowFileMenu()));
+    connect(m_menuFile, &QMenu::aboutToShow, this, &MainMenu::aboutToShowFileMenu);
 
     ADD_ACTION("File/NewTab", m_menuFile, IconProvider::newTabIcon(), tr("New Tab"), SLOT(newTab()), "Ctrl+T");
     ADD_ACTION("File/NewWindow", m_menuFile, IconProvider::newWindowIcon(), tr("&New Window"), SLOT(newWindow()), "Ctrl+N");
@@ -494,11 +494,11 @@ void MainMenu::init()
     m_menuFile->addSeparator();
 
     if (mApp->sessionManager()) {
-        QMenu* sessionsSubmenu = new QMenu(tr("Sessions"));
+        auto* sessionsSubmenu = new QMenu(tr("Sessions"));
         connect(sessionsSubmenu, SIGNAL(aboutToShow()), mApp->sessionManager(), SLOT(aboutToShowSessionsMenu()));
         m_menuFile->addMenu(sessionsSubmenu);
         action = new QAction(tr("Session Manager"), this);
-        connect(action, SIGNAL(triggered()), mApp->sessionManager(), SLOT(openSessionManagerDialog()));
+        connect(action, &QAction::triggered, mApp->sessionManager(), &SessionManager::openSessionManagerDialog);
         m_actions[QSL("File/SessionManager")] = action;
         m_menuFile->addAction(action);
         m_menuFile->addSeparator();
@@ -512,7 +512,7 @@ void MainMenu::init()
 
     // Edit menu
     m_menuEdit = new QMenu(tr("&Edit"));
-    connect(m_menuEdit, SIGNAL(aboutToShow()), this, SLOT(aboutToShowEditMenu()));
+    connect(m_menuEdit, &QMenu::aboutToShow, this, &MainMenu::aboutToShowEditMenu);
 
     ADD_ACTION("Edit/Undo", m_menuEdit, QIcon::fromTheme(QSL("edit-undo")), tr("&Undo"), SLOT(editUndo()), "Ctrl+Z");
     action->setShortcutContext(Qt::WidgetShortcut);
@@ -534,14 +534,14 @@ void MainMenu::init()
 
     // View menu
     m_menuView = new QMenu(tr("&View"));
-    connect(m_menuView, SIGNAL(aboutToShow()), this, SLOT(aboutToShowViewMenu()));
+    connect(m_menuView, &QMenu::aboutToShow, this, &MainMenu::aboutToShowViewMenu);
 
-    QMenu* toolbarsMenu = new QMenu(tr("Toolbars"));
-    connect(toolbarsMenu, SIGNAL(aboutToShow()), this, SLOT(aboutToShowToolbarsMenu()));
-    QMenu* sidebarMenu = new QMenu(tr("Sidebar"));
-    connect(sidebarMenu, SIGNAL(aboutToShow()), this, SLOT(aboutToShowSidebarsMenu()));
-    QMenu* encodingMenu = new QMenu(tr("Character &Encoding"));
-    connect(encodingMenu, SIGNAL(aboutToShow()), this, SLOT(aboutToShowEncodingMenu()));
+    auto* toolbarsMenu = new QMenu(tr("Toolbars"));
+    connect(toolbarsMenu, &QMenu::aboutToShow, this, &MainMenu::aboutToShowToolbarsMenu);
+    auto* sidebarMenu = new QMenu(tr("Sidebar"));
+    connect(sidebarMenu, &QMenu::aboutToShow, this, &MainMenu::aboutToShowSidebarsMenu);
+    auto* encodingMenu = new QMenu(tr("Character &Encoding"));
+    connect(encodingMenu, &QMenu::aboutToShow, this, &MainMenu::aboutToShowEncodingMenu);
 
     // Create menus to make shortcuts available even before first showing the menu
     m_window->createToolbarsMenu(toolbarsMenu);
@@ -562,17 +562,17 @@ void MainMenu::init()
     m_menuView->addSeparator();
     ADD_ACTION("View/PageSource", m_menuView, QIcon::fromTheme(QSL("text-html")), tr("&Page Source"), SLOT(showPageSource()), "Ctrl+U");
     action->setShortcutContext(Qt::WidgetShortcut);
-    ADD_CHECKABLE_ACTION("View/FullScreen", m_menuView, QIcon(), tr("&FullScreen"), SLOT(showFullScreen()), "F11");
+    ADD_CHECKABLE_ACTION("View/FullScreen", m_menuView, QIcon::fromTheme(QSL("view-fullscreen")), tr("&FullScreen"), SLOT(showFullScreen()), "F11");
 
     // Tools menu
     m_menuTools = new QMenu(tr("&Tools"));
-    connect(m_menuTools, SIGNAL(aboutToShow()), this, SLOT(aboutToShowToolsMenu()));
+    connect(m_menuTools, &QMenu::aboutToShow, this, &MainMenu::aboutToShowToolsMenu);
 
-    ADD_ACTION("Tools/WebSearch", m_menuTools, QIcon(), tr("&Web Search"), SLOT(webSearch()), "Ctrl+K");
+    ADD_ACTION("Tools/WebSearch", m_menuTools, QIcon::fromTheme(QSL("edit-find")), tr("&Web Search"), SLOT(webSearch()), "Ctrl+K");
     ADD_ACTION("Tools/SiteInfo", m_menuTools, QIcon::fromTheme(QSL("dialog-information")), tr("Site &Info"), SLOT(showSiteInfo()), "Ctrl+I");
     action->setShortcutContext(Qt::WidgetShortcut);
     m_menuTools->addSeparator();
-    ADD_ACTION("Tools/DownloadManager", m_menuTools, QIcon(), tr("&Download Manager"), SLOT(showDownloadManager()), "Ctrl+Y");
+    ADD_ACTION("Tools/DownloadManager", m_menuTools, QIcon::fromTheme(QSL("download")), tr("&Download Manager"), SLOT(showDownloadManager()), "Ctrl+Y");
     ADD_ACTION("Tools/CookiesManager", m_menuTools, QIcon(), tr("&Cookies Manager"), SLOT(showCookieManager()), "");
     ADD_ACTION("Tools/WebInspector", m_menuTools, QIcon(), tr("Web In&spector"), SLOT(toggleWebInspector()), "Ctrl+Shift+I");
     ADD_ACTION("Tools/ClearRecentHistory", m_menuTools, QIcon::fromTheme(QSL("edit-clear")), tr("Clear Recent &History"), SLOT(showClearRecentHistoryDialog()), "Ctrl+Shift+Del");
@@ -611,7 +611,7 @@ void MainMenu::init()
     // Other actions
     action = new QAction(QIcon::fromTheme(QSL("user-trash")), tr("Restore &Closed Tab"), this);
     action->setShortcut(QKeySequence(QSL("Ctrl+Shift+T")));
-    connect(action, SIGNAL(triggered()), this, SLOT(restoreClosedTab()));
+    connect(action, &QAction::triggered, this, &MainMenu::restoreClosedTab);
     m_actions[QSL("Other/RestoreClosedTab")] = action;
 
 #ifdef Q_OS_MACOS
