@@ -84,7 +84,8 @@ void BookmarksMenu::menuAboutToShow()
     Q_ASSERT(qobject_cast<Menu*>(sender()));
     Menu *menu = static_cast<Menu*>(sender());
 
-    foreach (QAction *action, menu->actions()) {
+    const auto menuActions = menu->actions();
+    for (QAction *action : menuActions) {
         BookmarkItem *item = static_cast<BookmarkItem*>(action->data().value<void*>());
         if (item && item->type() == BookmarkItem::Url && action->icon().isNull()) {
             action->setIcon(item->icon());
@@ -101,7 +102,7 @@ void BookmarksMenu::menuMiddleClicked(Menu* menu)
 
 void BookmarksMenu::bookmarkActivated()
 {
-    if (QAction* action = qobject_cast<QAction*>(sender())) {
+    if (auto* action = qobject_cast<QAction*>(sender())) {
         BookmarkItem* item = static_cast<BookmarkItem*>(action->data().value<void*>());
         Q_ASSERT(item);
         openBookmark(item);
@@ -110,7 +111,7 @@ void BookmarksMenu::bookmarkActivated()
 
 void BookmarksMenu::bookmarkCtrlActivated()
 {
-    if (QAction* action = qobject_cast<QAction*>(sender())) {
+    if (auto* action = qobject_cast<QAction*>(sender())) {
         BookmarkItem* item = static_cast<BookmarkItem*>(action->data().value<void*>());
         Q_ASSERT(item);
         openBookmarkInNewTab(item);
@@ -119,7 +120,7 @@ void BookmarksMenu::bookmarkCtrlActivated()
 
 void BookmarksMenu::bookmarkShiftActivated()
 {
-    if (QAction* action = qobject_cast<QAction*>(sender())) {
+    if (auto* action = qobject_cast<QAction*>(sender())) {
         BookmarkItem* item = static_cast<BookmarkItem*>(action->data().value<void*>());
         Q_ASSERT(item);
         openBookmarkInNewWindow(item);
@@ -188,7 +189,8 @@ void BookmarksMenu::refresh()
     BookmarksTools::addActionToMenu(this, this, mApp->bookmarks()->toolbarFolder());
     addSeparator();
 
-    foreach (BookmarkItem* child, mApp->bookmarks()->menuFolder()->children()) {
+    const auto children = mApp->bookmarks()->menuFolder()->children();
+    for (BookmarkItem* child : children) {
         BookmarksTools::addActionToMenu(this, this, child);
     }
 
