@@ -22,6 +22,7 @@
 
 #include <QApplication>
 #include <QDateTime>
+#include <QTimeZone>
 #include <QTimer>
 
 static QString dateTimeToString(const QDateTime &dateTime)
@@ -336,7 +337,7 @@ void HistoryModel::historyEntryAdded(const HistoryEntry &entry)
 
         m_todayItem = new HistoryItem(0);
         m_todayItem->setStartTimestamp(-1);
-        m_todayItem->setEndTimestamp(QDateTime(QDate::currentDate()).toMSecsSinceEpoch());
+        m_todayItem->setEndTimestamp(QDateTime(QDate::currentDate(), QTime(), QTimeZone::systemTimeZone()).toMSecsSinceEpoch());
         m_todayItem->title = tr("Today");
 
         m_rootItem->prependChild(m_todayItem);
@@ -466,17 +467,17 @@ void HistoryModel::init()
         QString itemName;
 
         if (timestampDate == today) {
-            endTimestamp = QDateTime(today).toMSecsSinceEpoch();
+            endTimestamp = QDateTime(today, QTime(), QTimeZone::systemTimeZone()).toMSecsSinceEpoch();
 
             itemName = tr("Today");
         }
         else if (timestampDate >= week) {
-            endTimestamp = QDateTime(week).toMSecsSinceEpoch();
+            endTimestamp = QDateTime(week, QTime(), QTimeZone::systemTimeZone()).toMSecsSinceEpoch();
 
             itemName = tr("This Week");
         }
         else if (timestampDate.month() == month.month() && timestampDate.year() == month.year()) {
-            endTimestamp = QDateTime(month).toMSecsSinceEpoch();
+            endTimestamp = QDateTime(month, QTime(), QTimeZone::systemTimeZone()).toMSecsSinceEpoch();
 
             itemName = tr("This Month");
         }
@@ -484,8 +485,8 @@ void HistoryModel::init()
             QDate startDate(timestampDate.year(), timestampDate.month(), timestampDate.daysInMonth());
             QDate endDate(startDate.year(), startDate.month(), 1);
 
-            timestamp = QDateTime(startDate, QTime(23, 59, 59)).toMSecsSinceEpoch();
-            endTimestamp = QDateTime(endDate).toMSecsSinceEpoch();
+            timestamp = QDateTime(startDate, QTime(23, 59, 59), QTimeZone::systemTimeZone()).toMSecsSinceEpoch();
+            endTimestamp = QDateTime(endDate, QTime(), QTimeZone::systemTimeZone()).toMSecsSinceEpoch();
             itemName = QString("%1 %2").arg(History::titleCaseLocalizedMonth(timestampDate.month()), QString::number(timestampDate.year()));
         }
 
