@@ -324,7 +324,11 @@ int LocationCompleterDelegate::viewItemDrawText(QPainter *p, const QStyleOptionV
                 highlightParts << highlightedPart;
             }
 
-            textLayout.setAdditionalFormats(highlightParts);
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+            textLayout.setFormats(QVector<QTextLayout::FormatRange>::fromList(highlightParts));
+#else
+            textLayout.setFormats(highlightParts);
+#endif
         }
     }
 
