@@ -34,6 +34,7 @@
 #include <QUrlQuery>
 #include <QWebEngineProfile>
 #include <QWebEngineUrlRequestJob>
+#include <QtWebEngineCoreVersion>
 
 static QString authorString(const char* name, const QString &mail)
 {
@@ -150,6 +151,7 @@ QString FalkonSchemeReply::startPage()
 
     sPage.append(QzTools::readAllFileContents(":html/start.html"));
     sPage.replace(QLatin1String("%ABOUT-IMG%"), QSL("qrc:icons/other/startpage.svg"));
+    sPage.replace(QLatin1String("%ABOUT-IMG-DARK%"), QSL("qrc:icons/other/startpage-dark.svg"));
 
     sPage.replace(QLatin1String("%TITLE%"), tr("Start Page"));
     sPage.replace(QLatin1String("%BUTTON-LABEL%"), tr("Search on Web"));
@@ -169,6 +171,7 @@ QString FalkonSchemeReply::aboutPage()
     if (aPage.isEmpty()) {
         aPage.append(QzTools::readAllFileContents(":html/about.html"));
         aPage.replace(QLatin1String("%ABOUT-IMG%"), QSL("qrc:icons/other/about.svg"));
+        aPage.replace(QLatin1String("%ABOUT-IMG-DARK%"), QSL("qrc:icons/other/about-dark.svg"));
         aPage.replace(QLatin1String("%COPYRIGHT-INCLUDE%"), QzTools::readAllFileContents(":html/copyright").toHtmlEscaped());
 
         aPage.replace(QLatin1String("%TITLE%"), tr("About Falkon"));
@@ -278,6 +281,7 @@ QString FalkonSchemeReply::configPage()
     if (cPage.isEmpty()) {
         cPage.append(QzTools::readAllFileContents(":html/config.html"));
         cPage.replace(QLatin1String("%ABOUT-IMG%"), QSL("qrc:icons/other/about.svg"));
+        cPage.replace(QLatin1String("%ABOUT-IMG-DARK%"), QSL("qrc:icons/other/about-dark.svg"));
 
         cPage.replace(QLatin1String("%TITLE%"), tr("Configuration Information"));
         cPage.replace(QLatin1String("%CONFIG%"), tr("Configuration Information"));
@@ -316,6 +320,7 @@ QString FalkonSchemeReply::configPage()
 #endif
                                                           ) +
                       QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Qt version"), qVersion()) +
+                      QString("<dt>%1</dt><dd>%2<dd>").arg(tr("QtWebEngine version"), QSL(QTWEBENGINECORE_VERSION_STR)) +
                       QString("<dt>%1</dt><dd>%2<dd>").arg(tr("Platform"), QzTools::operatingSystemLong()));
 
         cPage.replace(QLatin1String("%PATHS-TEXT%"),
