@@ -165,11 +165,12 @@ void SearchEnginesManager::restoreDefaults()
     duck.suggestionsUrl = "https://ac.duckduckgo.com/ac/?q=%s&type=list";
 
     Engine sp;
-    sp.name = "Startpage";
+    sp.name = "StartPage";
     sp.icon = QIcon(":/icons/sites/startpage.png");
-    sp.url = "https://www.startpage.com/sp/search?query=%s&cat=web&pl=opensearch";
+    sp.url = "https://startpage.com/do/search";
+    sp.postData = "query=%s&cat=web&language=english";
     sp.shortcut = "sp";
-    sp.suggestionsUrl = "https://www.startpage.com/osuggestions?q=%s";
+    sp.suggestionsUrl = "https://startpage.com/cgi-bin/csuggest?output=json&lang=english&query=%s";
 
     Engine wiki;
     wiki.name = "Wikipedia (en)";
