@@ -34,7 +34,7 @@ class FALKON_EXPORT PluginsManager : public QWidget
     Q_OBJECT
 
 public:
-    explicit PluginsManager(QWidget* parent = 0);
+    explicit PluginsManager(QWidget* parent = nullptr);
     ~PluginsManager();
 
     void load();
@@ -42,8 +42,10 @@ public:
 
 private Q_SLOTS:
     void settingsClicked();
+    void removeClicked();
     void currentChanged(QListWidgetItem* item);
     void itemChanged(QListWidgetItem* item);
+    void addFilter(const QString& newText);
 
     void refresh();
 
@@ -52,6 +54,7 @@ private:
 
     Ui::PluginsList* ui;
     bool m_loaded;
+    bool m_blockRefresh = false;
 };
 
 #endif // PLUGINSMANAGER_H
