@@ -55,7 +55,7 @@ ThemeManager::ThemeManager(QWidget* parent, Preferences* preferences)
                 continue;
             }
 
-            QListWidgetItem* item = new QListWidgetItem(ui->listWidget);
+            auto* item = new QListWidgetItem(ui->listWidget);
             item->setText(themeInfo.name);
             item->setIcon(themeInfo.icon);
             item->setData(Qt::UserRole, name);
@@ -84,7 +84,7 @@ void ThemeManager::showLicense()
 
     Theme currentTheme = m_themeHash[currentItem->data(Qt::UserRole).toString()];
 
-    LicenseViewer* v = new LicenseViewer(m_preferences);
+    auto* v = new LicenseViewer(m_preferences);
     v->setText(currentTheme.license);
     v->show();
 }
@@ -129,7 +129,7 @@ ThemeManager::Theme ThemeManager::parseTheme(const QString &path, const QString
     Theme info;
     info.isValid = false;
 
-    if (!QFile(path + "main.css").exists() || !QFile(path + "metadata.desktop").exists()) {
+    if (!QFile(path + QStringLiteral("main.css")).exists() || !QFile(path + "metadata.desktop").exists()) {
         info.isValid = false;
         return info;
     }
@@ -138,12 +138,7 @@ ThemeManager::Theme ThemeManager::parseTheme(const QString &path, const QString
     info.name = metadata.name();
     info.description = metadata.comment();
     info.author = metadata.value(QSL("X-Falkon-Author")).toString();
-#if QTCORE_VERSION >= QT_VERSION_CHECK(5, 10, 0)
     info.themePath = path.chopped(1);
-#else
-    info.themePath = path;
-    info.themePath.chop(1);
-#endif
 
     const QString iconName = metadata.icon();
     if (!iconName.isEmpty()) {
