@@ -35,8 +35,8 @@ class FALKON_EXPORT HistorySideBar : public QWidget
     Q_OBJECT
 
 public:
-    explicit HistorySideBar(BrowserWindow* window, QWidget* parent = 0);
-    ~HistorySideBar();
+    explicit HistorySideBar(BrowserWindow* window, QWidget* parent = nullptr);
+    ~HistorySideBar() override;
 
 private Q_SLOTS:
     void urlActivated(const QUrl &url);
