@@ -25,6 +25,7 @@
 #include "settings.h"
 
 #include <QMenu>
+#include <QActionGroup>
 
 QHash<QString, QPointer<SideBarInterface> > s_sidebars;
 
@@ -63,14 +64,14 @@ void SideBar::setWidget(QWidget* widget)
 void SideBar::showBookmarks()
 {
     m_titleBar->setTitle(tr("Bookmarks"));
-    BookmarksSidebar* bar = new BookmarksSidebar(m_window);
+    auto* bar = new BookmarksSidebar(m_window);
     setWidget(bar);
 }
 
 void SideBar::showHistory()
 {
     m_titleBar->setTitle(tr("History"));
-    HistorySideBar* bar = new HistorySideBar(m_window);
+    auto* bar = new HistorySideBar(m_window);
     setWidget(bar);
 }
 
@@ -102,7 +103,7 @@ void SideBarManager::createMenu(QMenu* menu)
     m_window->removeActions(menu->actions());
     menu->clear();
 
-    QActionGroup *group = new QActionGroup(menu);
+    auto *group = new QActionGroup(menu);
 
     QAction* act = menu->addAction(SideBar::tr("Bookmarks"), this, &SideBarManager::slotShowSideBar);
     act->setCheckable(true);
@@ -118,7 +119,7 @@ void SideBarManager::createMenu(QMenu* menu)
     act->setChecked(m_activeBar == QL1S("History"));
     group->addAction(act);
 
-    foreach (const QPointer<SideBarInterface> &sidebar, s_sidebars) {
+    for (const QPointer<SideBarInterface> &sidebar : qAsConst(s_sidebars)) {
         if (sidebar) {
             QAction* act = sidebar.data()->createMenuAction();
             act->setData(s_sidebars.key(sidebar));
@@ -146,14 +147,15 @@ void SideBarManager::removeSidebar(SideBarInterface *interface)
 
     s_sidebars.remove(id);
 
-    foreach (BrowserWindow* window, mApp->windows()) {
+    const auto windows = mApp->windows();
+    for (BrowserWindow* window : windows) {
         window->sideBarManager()->sideBarRemoved(id);
     }
 }
 
 void SideBarManager::slotShowSideBar()
 {
-    if (QAction* act = qobject_cast<QAction*>(sender())) {
+    if (auto* act = qobject_cast<QAction*>(sender())) {
         showSideBar(act->data().toString());
     }
 }
@@ -166,6 +168,10 @@ void SideBarManager::showSideBar(const QString &id, bool toggle)
 
     if (!m_sideBar) {
         m_sideBar = m_window->addSideBar();
+        connect(m_sideBar, &QObject::destroyed, this, [this]() {
+            m_activeBar.clear();
+            m_window->saveSideBarSettings();
+        });
     }
 
     if (id == m_activeBar) {
@@ -202,7 +208,7 @@ void SideBarManager::showSideBar(const QString &id, bool toggle)
 void SideBarManager::sideBarRemoved(const QString &id)
 {
     if (m_activeBar == id && m_sideBar) {
-        m_sideBar.data()->setWidget(Q_NULLPTR);
+        m_sideBar.data()->setWidget(nullptr);
         m_sideBar.data()->close();
     }
 }
