@@ -33,8 +33,8 @@ class FALKON_EXPORT TabStackedWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit TabStackedWidget(QWidget* parent = 0);
-    ~TabStackedWidget();
+    explicit TabStackedWidget(QWidget* parent = nullptr);
+    ~TabStackedWidget() override;
 
     ComboTabBar* tabBar();
     void setTabBar(ComboTabBar* tb);
