@@ -279,8 +279,8 @@ QString CertificateInfoWidget::clearCertSpecialSymbols(const QString &string)
     n.replace(QLatin1String("\\xC2\\xBD"), QLatin1String("1/2"));      // one half
     n.replace(QLatin1String("\\xC2\\xBE"), QLatin1String("3/4"));      // three quarters
     n.replace(QLatin1String("\\xCA\\xBF"), QLatin1String("\\x27"));    // c-single quote
-    n.replace(QLatin1String("\\xCC\\xA8"), QString());                 // modifier - under curve
-    n.replace(QLatin1String("\\xCC\\xB1"), QString());                 // modifier - under line
+    n.remove(QLatin1String("\\xCC\\xA8"));                 // modifier - under curve
+    n.remove(QLatin1String("\\xCC\\xB1"));                 // modifier - under line
 
     return n;
 }
@@ -288,7 +288,7 @@ QString CertificateInfoWidget::clearCertSpecialSymbols(const QString &string)
 QString CertificateInfoWidget::clearCertSpecialSymbols(const QStringList &stringList)
 {
     if (stringList.isEmpty()) {
-        return QString();
+        return {};
     }
 
     return clearCertSpecialSymbols(stringList.at(0));
@@ -307,7 +307,7 @@ QString CertificateInfoWidget::showCertInfo(const QString &string)
 QString CertificateInfoWidget::showCertInfo(const QStringList &stringList)
 {
     if (stringList.isEmpty()) {
-        return QString();
+        return {};
     }
 
     return showCertInfo(stringList.at(0));
