@@ -21,7 +21,11 @@
 #include <QWebEnginePage>
 #include <QWebEngineScript>
 #include <QWebEngineFullScreenRequest>
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+#include <QPrinter>
+#endif
 #include <QVector>
+#include <QElapsedTimer>
 
 #include "qzcommon.h"
 
@@ -92,10 +96,15 @@ private Q_SLOTS:
     void fullScreenRequested(QWebEngineFullScreenRequest fullScreenRequest);
     void featurePermissionRequested(const QUrl &origin, const QWebEnginePage::Feature &feature);
     void renderProcessTerminated(QWebEnginePage::RenderProcessTerminationStatus terminationStatus, int exitCode);
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+    void onCertificateError(QWebEngineCertificateError error);
+#endif
 
 private:
     bool acceptNavigationRequest(const QUrl &url, QWebEnginePage::NavigationType type, bool isMainFrame) override;
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
     bool certificateError(const QWebEngineCertificateError &error) override;
+#endif
     QStringList chooseFiles(FileSelectionMode mode, const QStringList &oldFiles, const QStringList &acceptedMimeTypes) override;
     QWebEnginePage* createWindow(QWebEnginePage::WebWindowType type) override;
 
@@ -104,7 +113,7 @@ private:
 
     static QString s_lastUploadLocation;
     static QUrl s_lastUnsupportedUrl;
-    static QTime s_lastUnsupportedUrlTime;
+    static QElapsedTimer s_lastUnsupportedUrlTime;
 
     DelayedFileWatcher* m_fileWatcher;
     QEventLoop* m_runningLoop;
