@@ -19,7 +19,11 @@
 
 #include "plugininterface.h"
 
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
 #include <PurposeWidgets/Menu>
+#else
+#include <Purpose/Menu>
+#endif
 
 class KWalletPasswordBackend;
 class KIOSchemeHandler;
