@@ -111,11 +111,11 @@ void PIM_Handler::populateWebViewMenu(QMenu* menu, WebView* view, const WebHitTe
         loadSettings();
     }
 
-    QMenu* pimMenu = new QMenu(tr("Insert Personal Information"));
-    pimMenu->setIcon(QIcon(":/PIM/data/PIM.png"));
+    auto* pimMenu = new QMenu(tr("Insert Personal Information"));
+    pimMenu->setIcon(QIcon(QStringLiteral(":/PIM/data/PIM.png")));
 
     if (!m_allInfo[PI_FirstName].isEmpty() && !m_allInfo[PI_LastName].isEmpty()) {
-        const QString fullname = m_allInfo[PI_FirstName] + " " + m_allInfo[PI_LastName];
+        const QString fullname = m_allInfo[PI_FirstName] + QLatin1Char(' ') + m_allInfo[PI_LastName];
         QAction* action = pimMenu->addAction(fullname, this, &PIM_Handler::pimInsert);
         action->setData(fullname);
     }
@@ -187,7 +187,7 @@ void PIM_Handler::pimInsert()
     if (!m_view || m_clickedPos.isNull())
         return;
 
-    QAction* action = qobject_cast<QAction*>(sender());
+    auto* action = qobject_cast<QAction*>(sender());
     if (!action)
         return;
 
@@ -206,7 +206,7 @@ void PIM_Handler::pimInsert()
 
 void PIM_Handler::pageLoadFinished()
 {
-    WebPage* page = qobject_cast<WebPage*>(sender());
+    auto* page = qobject_cast<WebPage*>(sender());
     if (!page) {
         return;
     }
@@ -242,15 +242,18 @@ QString PIM_Handler::matchingJsTable() const
     QHashIterator<PI_Type, QStringList> i(m_infoMatches);
     while (i.hasNext()) {
         i.next();
-        foreach (const QString &value, i.value()) {
+
+        const auto ivalues = i.value();
+        for (const QString &value : ivalues) {
             QString key = m_allInfo.value(i.key());
             key.replace(QL1C('"'), QL1S("\\\""));
             values.append(QSL("\"%1\":\"%2\",").arg(value, key));
         }
     }
 
-    if (!values.isEmpty())
+    if (!values.isEmpty()) {
         values = values.left(values.size() - 1);
+    }
 
     return QSL("{ %1 }").arg(values);
 }
