@@ -19,6 +19,14 @@
 // Make "signals:", "slots:" visible as access specifiers
 #define QT_ANNOTATE_ACCESS_SPECIFIER(a) __attribute__((annotate(#a)))
 
+// PYSIDE-711
+#include <QHstsPolicy>
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+#include <QWebEngineContextMenuData>
+#else
+#include <QWebEngineContextMenuRequest>
+#endif
+
 // 3rdparty
 #include "lineedit.h"
 #include "squeezelabelv1.h"
@@ -102,6 +110,7 @@
 #include "clickablelabel.h"
 #include "delayedfilewatcher.h"
 #include "desktopfile.h"
+#include "enhancedmenu.h"
 #include "iconprovider.h"
 #include "qztools.h"
 #include "sqldatabase.h"
