@@ -23,18 +23,26 @@
 #include "browserwindow.h"
 
 #include <QMenu>
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
 #include <QNetworkConfigurationManager>
+#endif
 
 SBI_NetworkIcon::SBI_NetworkIcon(BrowserWindow* window)
     : SBI_Icon(window)
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
     , m_networkConfiguration(new QNetworkConfigurationManager(this))
+#endif
 {
     setObjectName(QSL("sbi_networkicon"));
     setCursor(Qt::PointingHandCursor);
 
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
     onlineStateChanged(m_networkConfiguration->isOnline());
 
     connect(m_networkConfiguration, &QNetworkConfigurationManager::onlineStateChanged, this, &SBI_NetworkIcon::onlineStateChanged);
+#else
+    onlineStateChanged(true);
+#endif
     connect(this, &ClickableLabel::clicked, this, &SBI_NetworkIcon::showMenu);
 }
 
@@ -97,12 +105,18 @@ void SBI_NetworkIcon::updateToolTip()
 {
     QString tooltip = tr("Shows network status and manages proxy<br/><br/><b>Network:</b><br/>%1<br/><br/><b>Proxy:</b><br/>%2");
 
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
     if (m_networkConfiguration->isOnline()) {
         tooltip = tooltip.arg(tr("Connected"));
     }
     else {
         tooltip = tooltip.arg(tr("Offline"));
     }
+#else
+    // TODO QT6 - in Qt6 we're always reporting as online, should we just remove this functionality instead?
+    // Or is there a way to detect network status in Qt6?
+    tooltip = tooltip.arg(tr("Connected"));
+#endif
 
     switch (QNetworkProxy::applicationProxy().type()) {
     case QNetworkProxy::DefaultProxy:
@@ -125,7 +139,11 @@ void SBI_NetworkIcon::updateToolTip()
     setToolTip(tooltip);
 }
 
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
 void SBI_NetworkIcon::enterEvent(QEvent* event)
+#else
+void SBI_NetworkIcon::enterEvent(QEnterEvent* event)
+#endif
 {
     updateToolTip();
 
