@@ -97,7 +97,7 @@ void TabManagerDelegate::paint(QPainter* painter, const QStyleOptionViewItem &op
             opt2.state |= QStyle::State_On;
             break;
         }
-        style->drawPrimitive(QStyle::PE_IndicatorViewItemCheck, &opt2, painter, w);
+        style->drawPrimitive(QStyle::PE_IndicatorItemViewItemCheck, &opt2, painter, w);
     }
 
     // draw the icon
@@ -244,7 +244,11 @@ void TabManagerDelegate::viewItemDrawText(QPainter *p, const QStyleOptionViewIte
                 highlightParts << highlightedPart;
             }
 
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
             textLayout.setAdditionalFormats(highlightParts);
+#else
+            textLayout.setFormats(highlightParts);
+#endif
         }
     }
 
