@@ -14,10 +14,10 @@ class TabManagerSettings : public QDialog
 
 public:
     explicit TabManagerSettings(TabManagerPlugin* plugin, QWidget *parent = 0);
-    ~TabManagerSettings();
+    ~TabManagerSettings() override;
 
 public Q_SLOTS:
-    void accept();
+    void accept() override;
 
 private:
     Ui::TabManagerSettings* ui;
