@@ -20,7 +20,7 @@
 
 #include <QWidget>
 #include <QPointer>
-#include <QHash>
+#include <QMultiHash>
 #include <QTreeWidgetItem>
 
 namespace Ui
@@ -44,7 +44,11 @@ public:
 
     Qt::DropActions supportedDropActions() const override;
     QStringList mimeTypes() const override;
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
     QMimeData* mimeData(const QList<QTreeWidgetItem*> items) const override;
+#else
+    QMimeData* mimeData(const QList<QTreeWidgetItem*> &items) const override;
+#endif
     bool dropMimeData(QTreeWidgetItem *parent, int index, const QMimeData *data, Qt::DropAction action) override;
 
     void setEnableDragTabs(bool enable);
@@ -68,10 +72,10 @@ public:
     explicit TabManagerWidget(BrowserWindow* mainClass, QWidget* parent = 0, bool defaultWidget = false);
     ~TabManagerWidget() override;
 
-    void closeSelectedTabs(const QHash<BrowserWindow*, WebTab*> &tabsHash);
-    void detachSelectedTabs(const QHash<BrowserWindow*, WebTab*> &tabsHash);
-    bool bookmarkSelectedTabs(const QHash<BrowserWindow*, WebTab*> &tabsHash);
-    void unloadSelectedTabs(const QHash<BrowserWindow*, WebTab*> &tabsHash);
+    void closeSelectedTabs(const QMultiHash<BrowserWindow*, WebTab*> &tabsHash);
+    void detachSelectedTabs(const QMultiHash<BrowserWindow*, WebTab*> &tabsHash);
+    bool bookmarkSelectedTabs(const QMultiHash<BrowserWindow*, WebTab*> &tabsHash);
+    void unloadSelectedTabs(const QMultiHash<BrowserWindow*, WebTab*> &tabsHash);
 
     void setGroupType(GroupType type);
 
