@@ -240,5 +240,11 @@ void TabListView::updateVisibility()
 
 void TabListView::updateHeight()
 {
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
     setFixedHeight(m_delegate->sizeHint(viewOptions(), QModelIndex()).height());
+#else
+    QStyleOptionViewItem option;
+    initViewItemOption(&option);
+    setFixedHeight(m_delegate->sizeHint(option, QModelIndex()).height());
+#endif
 }
